@@ -37,6 +37,34 @@ def set_img_background():
         img.save(iname)
 
 
+def fmt_img_color():
+    from .ImageTools.ColorTools import formatOneColor, get_color_from_str
+
+    try:
+        img = sys.argv[2]
+        if img == '-help':
+            raise IndexError
+        if not os.path.exists(img):
+            qs_default_console.log(qs_error_string, 'No Such File: %s' % img)
+            return
+        to = sys.argv[3]
+        try:
+            exp = sys.argv[4:]
+        except IndexError:
+            exp = '0,0,0,0'
+    except IndexError:
+        qs_default_console.log(qs_error_string,
+                               'Usage: qs fmti <picture> <to_color> [except_color: default transparency]')
+        return
+    else:
+        to = get_color_from_str(to)
+        exp = [get_color_from_str(i) for i in exp]
+        img = formatOneColor(img, to, exp)
+        iname = sys.argv[2].split('.')
+        iname = iname[0] + '_fmt.' + ''.join(iname[1:])
+        img.save(iname)
+
+
 def v2gif():
     """视频转gif | video to gif"""
     from .ImageTools.VideoTools import video_2_gif
@@ -102,13 +130,43 @@ def icat():
     """Mac::iTerm下预览图片 | Preview the picture under Mac::iTerm"""
     try:
         path = sys.argv[2]
-        is_url = '-u' in sys.argv or \
+        is_url = '-open_url' in sys.argv or \
                  (not os.path.exists(path) and (path.startswith('http://') or path.startswith('https://')))
         if not os.path.exists(path) and not is_url:
             qs_default_console.log(qs_error_string, 'No such file:', path)
             raise FileNotFoundError
     except:
-        qs_default_console.log(qs_error_string, 'Usage: qs icat <img path/url> [-u if is url]')
+        qs_default_console.log(qs_error_string, 'Usage: qs icat <img path/url> [-open_url if is url]')
     else:
         from .ImageTools.ImagePreview import image_preview
         image_preview(open(path)) if not is_url else image_preview(path, is_url)
+
+
+def i2png():
+    try:
+        imgs = sys.argv[2:]
+    except IndexError:
+        qs_default_console.log(qs_error_string, 'Usage: qs i2png <imgs...>')
+    else:
+        from .ImageTools.ImageTools import topng
+        for imgPath in imgs:
+            topng(imgPath)
+
+
+def i2jpg():
+    try:
+        imgs = sys.argv[2:]
+    except IndexError:
+        qs_default_console.log(qs_error_string, 'Usage: qs i2jpg <imgs...>')
+    else:
+        from .ImageTools.ImageTools import tojpg
+        for imgPath in imgs:
+            tojpg(imgPath)
+
+
+def vsta():
+    from .ImageTools.VideoTools import set_video_audio
+    try:
+        set_video_audio(*sys.argv[2:])
+    except Exception as e:
+        qs_default_console.log(qs_error_string, f'{repr(e)}\nUsage: qs vsta <video> <audio>')
